==> ejc-scientific-api-3.0.0-20250307.095914-46-sources.jar: com/ejianc/business/scientific/sci/work/vo/WorkTimeReportVO.java <==
package com.ejianc.business.scientific.sci.work.vo;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @Author: caojie
 * @CreateTime:2025-03-06 14:31
 * @Version: 1.0
 */
public class WorkTimeReportVO implements Serializable {
    private static final long serialVersionUID = 5694768153454891697L;

    private Long orgId; // 所属组织id
    private String orgName; // 所属组织

    private Long projectId; // 科研项目主键
    private String projectName; // 科研项目名称

    private Long userId; // 人员主键
    private String userName; // 人员名称
    private String userMobile; // 联系方式
    private Long postId; // 职务主键
    private String postName; // 职务名称
    private String professional; // 职称
    private String duty; // 课题内职务
    private BigDecimal userPlanTotalHour; // 计划工时(月)
    private BigDecimal userTotalHour; // 累计工时(月)
    private BigDecimal userHour; // 本月工时
    private String yearMonth; // 月份

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserMobile() {
        return userMobile;
    }

    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }

    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public String getProfessional() {
        return professional;
    }

    public void setProfessional(String professional) {
        this.professional = professional;
    }

    public String getDuty() {
        return duty;
    }

    public void setDuty(String duty) {
        this.duty = duty;
    }

    public BigDecimal getUserPlanTotalHour() {
        return userPlanTotalHour;
    }

    public void setUserPlanTotalHour(BigDecimal userPlanTotalHour) {
        this.userPlanTotalHour = userPlanTotalHour;
    }

    public BigDecimal getUserTotalHour() {
        return userTotalHour;
    }

    public void setUserTotalHour(BigDecimal userTotalHour) {
        this.userTotalHour = userTotalHour;
    }

    public BigDecimal getUserHour() {
        return userHour;
    }

    public void setUserHour(BigDecimal userHour) {
        this.userHour = userHour;
    }

    public String getYearMonth() {
        return yearMonth;
    }

    public void setYearMonth(String yearMonth) {
        this.yearMonth = yearMonth;
    }
}

==> ejc-scientific-api-3.0.0-20250901.130824-93-sources.jar: com/ejianc/business/scientific/sci/work/vo/WorkTimeReportVO.java <==
package com.ejianc.business.scientific.sci.work.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

/**
 * @Author: caojie
 * @CreateTime:2025-03-06 14:31
 * @Version: 1.0
 */
public class WorkTimeReportVO implements Serializable {
    private static final long serialVersionUID = 5694768153454891697L;

    private Long orgId; // 所属组织id
    private String orgName; // 所属组织

    private String deptName; //部门名称

    private Long projectId; // 科研项目主键
    private String projectName; // 科研项目名称

    private Long userId; // 人员主键
    private String userName; // 人员名称
    private String userMobile; // 联系方式
    private Long postId; // 职务主键
    private String postName; // 职务名称
    private String professional; // 职称
    private String duty; // 课题内职务
    private BigDecimal userPlanTotalHour; // 计划工时(月)
    private BigDecimal userTotalHour; // 累计工时(月)
    private BigDecimal userHour; // 本月工时
    private String yearMonth; // 月份

    private List<Long> orgIds;

    private Integer startLine;
    private Integer pageSize;

    private String searchText;

    public String getSearchText() {
        return searchText;
    }

    public void setSearchText(String searchText) {
        this.searchText = searchText;
    }

    public List<Long> getOrgIds() {
        return orgIds;
    }

    public void setOrgIds(List<Long> orgIds) {
        this.orgIds = orgIds;
    }

    public Integer getStartLine() {
        return startLine;
    }

    public void setStartLine(Integer startLine) {
        this.startLine = startLine;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserMobile() {
        return userMobile;
    }

    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }

    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }

    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }

    public String getProfessional() {
        return professional;
    }

    public void setProfessional(String professional) {
        this.professional = professional;
    }

    public String getDuty() {
        return duty;
    }

    public void setDuty(String duty) {
        this.duty = duty;
    }

    public BigDecimal getUserPlanTotalHour() {
        return userPlanTotalHour;
    }

    public void setUserPlanTotalHour(BigDecimal userPlanTotalHour) {
        this.userPlanTotalHour = userPlanTotalHour;
    }

    public BigDecimal getUserTotalHour() {
        return userTotalHour;
    }

    public void setUserTotalHour(BigDecimal userTotalHour) {
        this.userTotalHour = userTotalHour;
    }

    public BigDecimal getUserHour() {
        return userHour;
    }

    public void setUserHour(BigDecimal userHour) {
        this.userHour = userHour;
    }

    public String getYearMonth() {
        return yearMonth;
    }

    public void setYearMonth(String yearMonth) {
        this.yearMonth = yearMonth;
    }
}
